Struct Camera

pub struct Camera {
    pub projection: Option<ProjectionMethod>,
    pub position: Vector3F32,
    pub rotation: QuaternionF32,
    pub depth_range: Range<f32>,
}
A camera

Examples

let c = Camera {
    projection: Some(ProjectionMethod::Orthographic { size: 5.0 }),
    position: Vector3::ZERO, rotation: Quaternion::ONE,
    depth_range: 1.0 .. 9.0
};
let (mv, mp) = c.matrixes(1.0);
assert_eq!(mv.clone() * Vector3(5.0, 0.0, 1.0), Vector4(5.0, 0.0, 1.0, 1.0));
assert_eq!(mp * mv * Vector3(5.0, 0.0, 1.0), Vector4(1.0, 0.0, 0.0, 1.0));

Fields

projection: Option<ProjectionMethod>

Projection method of the camera. None indicates no projection(only adjust aspect ratio)

position: Vector3F32

Eye position of the camera.

rotation: QuaternionF32

Eye direction of the camera.

depth_range: Range<f32>

Z range to be rendered.

Implementations

Source

impl Camera

pub fn projection_matrix(&self, aspect_wh: f32) -> Matrix4F32

calculates the camera projection matrix

pub fn view_matrix(&self) -> Matrix4F32

calculates the camera view matrix

pub fn view_projection_matrix(&self, aspect_wh: f32) -> Matrix4F32

calculates the camera transform(view and projection) matrix

pub fn matrixes(&self, aspect_wh: f32) -> (Matrix4F32, Matrix4F32)

calculates the camera view matrix and the projection matrix(returns in this order)

pub fn look_at(&mut self, target: Vector3F32)

Sets rotation of the camera to look at a point